==> vux-2.9.6.tgz: package/README.md <==
<p align="center">
  <a href="http://vux.li">
    <img src="https://i.loli.net/2017/11/20/5a12187ebf2e0.png" width="175">
  </a>
</p>
<p align="center">Be Cool with Vue@^2.3.0 and WeUI.</p>

<p align="center">
  <a href="https://vux.li/demos/v2?x-page=github">
    <img src="https://static.vux.li/demo_v2_doc_home.png" width="100" alt="">
  </a>
  <br>
  <a href="https://vux.li/demos/v2?x-page=github">
    Live Demo >>
  </a>
  <br>
  <br>
  <a href="https://github.com/airyland/vux">
    <img src="https://img.shields.io/github/stars/airyland/vux.svg?style=social&label=Star" alt="">
  </a>
  <a href="https://github.com/airyland/vux">
    <img src="https://img.shields.io/github/forks/airyland/vux.svg?style=social&label=Fork" alt="">
  </a>
  <a href="https://github.com/airyland/vux">
    <img src="https://img.shields.io/github/watchers/airyland/vux.svg?style=social&label=Watch" alt="">
  </a>
  <br>
  <br>
  <a href="https://travis-ci.org/airyland/vux">
    <img src="https://api.travis-ci.org/airyland/vux.svg?branch=v2" alt="">
  </a>
  <a href="https://codecov.io/gh/airyland/vux/branch/v2">
    <img src="https://img.shields.io/codecov/c/github/airyland/vux/v2.svg" alt="">
  </a>
  <br>
  <a href="https://github.com/airyland/vux/issues">
    <img src="https://img.shields.io/github/issues/airyland/vux.svg?style=flat-square" alt="">
  </a>
  <a href="https://github.com/airyland/vux/issues">
    <img src="http://isitmaintained.com/badge/resolution/airyland/vux.svg?style=flat-square" alt="">
  </a>
  <a href="https://github.com/airyland/vux/graphs/contributors">
    <img src="https://img.shields.io/github/contributors/airyland/vux.svg?style=flat-square" alt="">
  </a>
  <br>
  <a href="https://www.npmjs.com/package/vux">
    <img src="https://img.shields.io/npm/l/vux.svg?style=flat-square" alt="">
  </a>
  <a href="https://www.npmjs.com/package/vux">
    <img src="https://img.shields.io/npm/v/vux.svg?style=flat-square" alt="">
  </a>
  <a href="https://www.npmjs.com/package/vux">
    <img src="https://img.shields.io/npm/dm/vux.svg?style=flat-square" alt="">
  </a>
  <a href="https://www.npmjs.com/package/vux">
    <img src="https://img.shields.io/npm/dt/vux.svg?style=flat-square" alt="">
  </a>
  <br>
  <br>
</p>

## Sponsors

<p align="center">
  <a href="https://www.sb/?utm_source=vux">
    <img src="http://wx1.sinaimg.cn/mw690/0060lm7Tly1ftmvim3r34j3056034wee.jpg" height="100">
  </a>
</p>

<p align="center">
  <a href="https://www.upyun.com/">
    <img src="https://ww1.sinaimg.cn/large/663d3650gy1fs3l83hokej20b4040weg.jpg" height="80">
  </a>
</p>

## 我们的产品

<p align="center">
  <a href="https://wereader.app?utm_source=vux-github">
    <img src="https://i.loli.net/2019/12/30/SM4y7mfunjvhWEc.png" width="125">
  </a>
</p>

<p align="center">
  <a href="https://werss.app?utm_source=vux-github">
    <img src="https://cdn.weapp.design/werss/werss-logo.png" width="250">
  </a>
</p>

## Requirements

+ vue@^2.3.0(for .sync modifier)
+ webpack@^2.0
+ node@^7.6(development)

## Docs

+ [中文文档](https://vux.li/)
+ English(working)

## Issues

> 不按照 [issue generator](https://doc.vux.li/issue-generator/#/zh-CN) 来提交的会被关闭并 `block`，毕竟提醒每一个故意忽略(眼瞎、文盲或者缺少礼貌？)`issue template`的人也是件很浪费时间的事。

- `VUX` 并不是大团队维护的项目，**没有捐赠，纯靠热情**，维护者有权决定什么时候处理什么问题，什么问题不处理。<br>**入坑请万分谨慎**。

- UI 组件库和样式、功能灵活性是矛盾的。如果你需要一个高度自定义的组件库，VUX 并不适合你(即使已经在尽力提供样式变量)，请不要使用，因为大部分人会抱怨的(并且只会抱怨)。

## Quick Start

> [vux2 template](https://github.com/airyland/vux2) is directly modified from Vue official [webpack template](https://github.com/vuejs-templates/webpack).

``` bash
npm install vue-cli -g
vue init airyland/vux2 projectPath

cd projectPath
npm install // or yarn
npm run dev // or yarn dev
```

## Get notified

<p align="center">
  <img src="https://ws1.sinaimg.cn/large/663d3650gy1fpno3msj6wj20dw0dw748.jpg" alt="" width="100">
  <br>
  <span>Scan with Wechat</span>
</p>

## Maintainers

+ [airyland](https://github.com/airyland)
+ [lichunqiang](https://github.com/lichunqiang)
+ [graysheeep](https://github.com/graysheeep)
+ [unclay](https://github.com/unclay)
+ [wg5945](https://github.com/wg5945)
+ [Sapphire2k](https://github.com/Sapphire2k)

## Vux is Inspired or Powered By:

+ [Vue](https://github.com/vuejs/vue)
+ [WeUI](https://github.com/weui/weui)
+ [FrozenUI](https://github.com/frozenui/frozenui)
+ [Ant Design](https://github.com/ant-design/ant-design)
+ [Ant Design Mobile](http://github.com/ant-design/ant-design-mobile)
+ [XScroll](https://github.com/huxiaoqi567/xscroll)
+ [Ionic](https://github.com/driftyco/ionic)
+ [SUI Mobile](https://github.com/sdc-alibaba/SUI-Mobile)
+ [PhotoSwipe](https://github.com/dimsemenov/PhotoSwipe)
+ [WePayUI](https://github.com/wepayui/wepayui)
+ [autosize](https://github.com/jackmoore/autosize)(MIT)
+ [buefy](https://github.com/buefy/buefy)

## License

[MIT](https://github.com/airyland/vux/blob/v2/LICENSE)

==> vux-2.11.1.tgz: package/README.md <==
<p align="center">
  <a href="http://vux.li">
    <img src="https://i.loli.net/2017/11/20/5a12187ebf2e0.png" width="175">
  </a>
</p>
<p align="center">Be Cool with Vue@^2.3.0 and WeUI.</p>

<p align="center">
  <a href="https://vux.li/demos/v2?x-page=github">
    <img src="https://static.vux.li/demo_v2_doc_home.png" width="100" alt="">
  </a>
  <br>
  <a href="https://vux.li/demos/v2?x-page=github">
    Live Demo >>
  </a>
  <br>
  <br>
  <a href="https://github.com/airyland/vux">
    <img src="https://img.shields.io/github/stars/airyland/vux.svg?style=social&label=Star" alt="">
  </a>
  <a href="https://github.com/airyland/vux">
    <img src="https://img.shields.io/github/forks/airyland/vux.svg?style=social&label=Fork" alt="">
  </a>
  <a href="https://github.com/airyland/vux">
    <img src="https://img.shields.io/github/watchers/airyland/vux.svg?style=social&label=Watch" alt="">
  </a>
  <br>
  <br>
  <a href="https://travis-ci.org/airyland/vux">
    <img src="https://api.travis-ci.org/airyland/vux.svg?branch=v2" alt="">
  </a>
  <a href="https://codecov.io/gh/airyland/vux/branch/v2">
    <img src="https://img.shields.io/codecov/c/github/airyland/vux/v2.svg" alt="">
  </a>
  <br>
  <a href="https://github.com/airyland/vux/issues">
    <img src="https://img.shields.io/github/issues/airyland/vux.svg?style=flat-square" alt="">
  </a>
  <a href="https://github.com/airyland/vux/issues">
    <img src="http://isitmaintained.com/badge/resolution/airyland/vux.svg?style=flat-square" alt="">
  </a>
  <a href="https://github.com/airyland/vux/graphs/contributors">
    <img src="https://img.shields.io/github/contributors/airyland/vux.svg?style=flat-square" alt="">
  </a>
  <br>
  <a href="https://www.npmjs.com/package/vux">
    <img src="https://img.shields.io/npm/l/vux.svg?style=flat-square" alt="">
  </a>
  <a href="https://www.npmjs.com/package/vux">
    <img src="https://img.shields.io/npm/v/vux.svg?style=flat-square" alt="">
  </a>
  <a href="https://www.npmjs.com/package/vux">
    <img src="https://img.shields.io/npm/dm/vux.svg?style=flat-square" alt="">
  </a>
  <a href="https://www.npmjs.com/package/vux">
    <img src="https://img.shields.io/npm/dt/vux.svg?style=flat-square" alt="">
  </a>
  <br>
  <br>
</p>

## Sponsors

<p align="center">
  <a href="https://www.sb/?utm_source=vux">
    <img src="http://wx1.sinaimg.cn/mw690/0060lm7Tly1ftmvim3r34j3056034wee.jpg" height="100">
  </a>
</p>

<p align="center">
  <a href="https://www.upyun.com/">
    <img src="https://ww1.sinaimg.cn/large/663d3650gy1fs3l83hokej20b4040weg.jpg" height="80">
  </a>
</p>

## 我们的产品

<p align="center">
  <a href="https://wereader.app?utm_source=vux-github">
    <img src="https://i.loli.net/2019/12/30/SM4y7mfunjvhWEc.png" width="125">
  </a>
</p>

<p align="center">
  <a href="https://werss.app?utm_source=vux-github">
    <img src="https://cdn.weapp.design/werss/werss-logo.png" width="250">
  </a>
</p>

## Requirements

+ vue@^2.3.0(for .sync modifier)
+ webpack@^2.0
+ node@^7.6(development)

## Docs

+ [中文文档](https://vux.li/)
+ English(working)

## Issues

> 不按照 [issue generator](https://doc.vux.li/en/contribution/issue.html) 来提交的会被关闭并 `block`，毕竟提醒每一个故意忽略(眼瞎、文盲或者缺少礼貌？)`issue template`的人也是件很浪费时间的事。

- `VUX` 并不是大团队维护的项目，**没有捐赠，纯靠热情**，维护者有权决定什么时候处理什么问题，什么问题不处理。<br>**入坑请万分谨慎**。

- UI 组件库和样式、功能灵活性是矛盾的。如果你需要一个高度自定义的组件库，VUX 并不适合你(即使已经在尽力提供样式变量)，请不要使用，因为大部分人会抱怨的(并且只会抱怨)。

## Quick Start

> [vux2 template](https://github.com/airyland/vux2) is directly modified from Vue official [webpack template](https://github.com/vuejs-templates/webpack).

``` bash
npm install vue-cli -g
vue init airyland/vux2 projectPath

cd projectPath
npm install // or yarn
npm run dev // or yarn dev
```

## Get notified

<p align="center">
  <img src="https://ws1.sinaimg.cn/large/663d3650gy1fpno3msj6wj20dw0dw748.jpg" alt="" width="100">
  <br>
  <span>Scan with Wechat</span>
</p>

## Maintainers

+ [airyland](https://github.com/airyland)
+ [lichunqiang](https://github.com/lichunqiang)
+ [graysheeep](https://github.com/graysheeep)
+ [unclay](https://github.com/unclay)
+ [wg5945](https://github.com/wg5945)
+ [Sapphire2k](https://github.com/Sapphire2k)

## Vux is Inspired or Powered By:

+ [Vue](https://github.com/vuejs/vue)
+ [WeUI](https://github.com/weui/weui)
+ [FrozenUI](https://github.com/frozenui/frozenui)
+ [Ant Design](https://github.com/ant-design/ant-design)
+ [Ant Design Mobile](http://github.com/ant-design/ant-design-mobile)
+ [XScroll](https://github.com/huxiaoqi567/xscroll)
+ [Ionic](https://github.com/driftyco/ionic)
+ [SUI Mobile](https://github.com/sdc-alibaba/SUI-Mobile)
+ [PhotoSwipe](https://github.com/dimsemenov/PhotoSwipe)
+ [WePayUI](https://github.com/wepayui/wepayui)
+ [autosize](https://github.com/jackmoore/autosize)(MIT)
+ [buefy](https://github.com/buefy/buefy)

## License

[MIT](https://github.com/airyland/vux/blob/v2/LICENSE)
